==> evac-1.0.0.tar.gz: evac/tests/src/Unit/Utility/NoRFCWarningsValidatorTest.php <==
<?php

namespace Drupal\Tests\evac\Unit\Utility;

use Drupal\evac\Utility\NoRFCWarningsValidator;
use Egulias\EmailValidator\Validation\NoRFCWarningsValidation;
use PHPUnit\Framework\TestCase;

/**
 * Tests the NoRFCWarningsValidator utility class.
 *
 * @coversDefaultClass \Drupal\evac\Utility\NoRFCWarningsValidator
 * @group evac
 */
class NoRFCWarningsValidatorTest extends TestCase {

  /**
   * @covers ::isValid
   */
  public function testIsValid() {
    // Note that \Drupal\Component\Utility\EmailValidator wraps
    // \Egulias\EmailValidator\EmailValidator so we don't do anything more than
    // test that the wrapping works since the dependency has its own test
    // coverage.
    $validator = new NoRFCWarningsValidator();

    // Examples are copied from
    // \Egulias\EmailValidator\Tests\EmailValidator\Validation\NoRFCWarningsValidationTest.
    $valid = 'example@example.com';
    $this->assertTrue($validator->isValid($valid), "Email $valid should pass.");

    $invalid = 'test()@example.com';
    $this->assertFalse($validator->isValid($invalid), "Email $invalid should fail.");
  }

  /**
   * @covers ::isValid
   */
  public function testIsValidException() {
    $validator = new NoRFCWarningsValidator();
    $this->expectException(\BadMethodCallException::class);
    $this->expectExceptionMessage('Calling \Drupal\evac\Utility\NoRFCWarningsValidator::isValid() with the second argument is not supported. See https://www.drupal.org/node/2997196');
    $validator->isValid('example@example.com', (new NoRFCWarningsValidation()));
  }

}

==> evac-1.0.1.tar.gz: evac/tests/src/Unit/Utility/NoRFCWarningsValidatorTest.php <==
<?php

namespace Drupal\Tests\evac\Unit\Utility;

use Drupal\evac\Utility\NoRFCWarningsValidator;
use Egulias\EmailValidator\Validation\NoRFCWarningsValidation;
use PHPUnit\Framework\TestCase;

/**
 * Tests the NoRFCWarningsValidator utility class.
 *
 * @coversDefaultClass \Drupal\evac\Utility\NoRFCWarningsValidator
 * @group evac
 */
class NoRFCWarningsValidatorTest extends TestCase {

  /**
   * @covers ::isValid
   */
  public function testIsValid() {
    // Note that \Drupal\Component\Utility\EmailValidator wraps
    // \Egulias\EmailValidator\EmailValidator, so we don't do anything more than
    // test that the wrapping works since the dependency has its own test
    // coverage.
    $validator = new NoRFCWarningsValidator();

    // Examples are copied from
    // \Egulias\EmailValidator\Tests\EmailValidator\Validation\NoRFCWarningsValidationTest.
    $valid = 'example@example.com';
    $this->assertTrue($validator->isValid($valid), "Email $valid should pass.");

    $invalid = 'test()@example.com';
    $this->assertFalse($validator->isValid($invalid), "Email $invalid should fail.");
  }

  /**
   * @covers ::isValid
   */
  public function testIsValidException() {
    $validator = new NoRFCWarningsValidator();
    $this->expectException(\BadMethodCallException::class);
    $this->expectExceptionMessage('Calling \Drupal\evac\Utility\NoRFCWarningsValidator::isValid() with the second argument is not supported. See https://www.drupal.org/node/2997196');
    $validator->isValid('example@example.com', (new NoRFCWarningsValidation()));
  }

}
